unit main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, ShortcutList, ShortcutBar, StdCtrls, CommCtrl, Buttons,
  ExtCtrls, Menus, ShortcutButton;

type
  TMainForm = class(TForm)
    ImageList: TImageList;
    BackPanel: TPanel;
    DetailPanel: TPanel;
    TitlePanel: TPanel;
    ListView: TListView;
    Splitter1: TSplitter;
    Panel1: TPanel;
    TitleImage: TPaintBox;
    TitleLabel: TLabel;
    Label1: TLabel;
    ShortcutBar: TShortcutBar;
    ShortcutSheet1: TShortcutSheet;
    ShortcutList1: TShortcutList;
    ShortcutSheet2: TShortcutSheet;
    ShortcutList2: TShortcutList;
    ShortcutSheet3: TShortcutSheet;
    ShortcutList3: TShortcutList;
    procedure ShortcutListClick(Sender: TObject);
    procedure TitleImagePaint(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ListViewMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure ShortcutListDragOver(Sender, Source: TObject; X, Y: Integer;
      State: TDragState; var Accept: Boolean);
    procedure ShortcutListDragDrop(Sender, Source: TObject; X,
      Y: Integer);
  private
    { Private declarations }
    FTitleImageIndex :Integer;
    FDragItem  :TListItem;
    FDragStrings  :TStringList;
    FDragIndex :Integer;
    FCurrentSection :TShortcutItem;
    procedure SetTitleImageIndex(Value :Integer);
    procedure ChangeSection(ShortcutItem :TShortcutItem);
  public
    { Public declarations }
    property TitleImageIndex :Integer read FTitleImageIndex write SetTitleImageIndex;
  end;

var
  MainForm: TMainForm;

implementation

Uses
  ShortcutItemsEditor;

{$R *.DFM}

procedure TMainForm.FormCreate(Sender: TObject);

Begin
  ShortcutList1.Items[0].Data:=TStringList.Create;
  TStringList(ShortcutList1.Items[0].Data).LoadFromFile(ExtractFilePath(Application.Exename)+'trees.txt');
  ChangeSection(ShortcutList1.Items[0]);
End;

procedure TMainForm.FormDestroy(Sender: TObject);

Var
  i :Integer;

Begin
  With ShortcutList1 Do
    For i:=0 To Items.Count-1 Do
      TStringList(Items[i].Data).Free;
  With ShortcutList2 Do
    For i:=0 To Items.Count-1 Do
      TStringList(Items[i].Data).Free;
  With ShortcutList3 Do
    For i:=0 To Items.Count-1 Do
      TStringList(Items[i].Data).Free;
End;

procedure TMainForm.ShortcutListClick(Sender: TObject);

Begin
  ChangeSection((Sender As TShortcutList).ActiveItem);
End;

procedure TMainForm.TitleImagePaint(Sender: TObject);

Begin
  ImageList.Draw(TitleImage.Canvas,2,2,TitleImageIndex);
End;

procedure TMainForm.SetTitleImageIndex(Value :Integer);

Begin
  If Value=FTitleImageIndex Then
    Exit;
  FTitleImageIndex:=Value;
  TitleImage.Invalidate;
End;

procedure TMainForm.ChangeSection(ShortcutItem :TShortcutItem);

Var
  Strings :TStringList;
  i       :Integer;

Begin
  FCurrentSection:=ShortcutItem;
  TitleLabel.Caption:=ShortcutItem.Caption;
  TitleImageIndex:=ShortcutItem.ImageIndex;
  With ListView.Items Do
    Begin
      BeginUpdate;
      Clear;
      If ShortcutItem.Data<>Nil Then
        Begin
          Strings:=TStringList(ShortcutItem.Data);
          For i:=0 To Strings.Count-1 Do
            With Add Do
              Begin
                Caption:=Strings[i];
                Data:=Strings;
              End;
        End;
      EndUpdate;
    End;
End;

procedure TMainForm.ListViewMouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);

Begin
  FDragItem:=ListView.GetItemAt(X,Y);
  If FDragItem<>Nil Then
    Begin
      FDragStrings:=TStringList(FDragItem.Data);
      FDragIndex:=FDragItem.Index;
      ListView.BeginDrag(False);
    End;
End;

procedure TMainForm.ShortcutListDragOver(Sender, Source: TObject; X,
  Y: Integer; State: TDragState; var Accept: Boolean);

Begin
  Accept:=(Sender As TShortcutList).ActiveItem<>Nil;
End;

procedure TMainForm.ShortcutListDragDrop(Sender, Source: TObject; X,
  Y: Integer);

Begin
  With (Sender As TShortcutList).ActiveItem Do
    Begin
      If Data=Nil Then
        Data:=TStringList.Create;
      TStringList(Data).Add(FDragStrings[FDragIndex]);
      FDragStrings.Delete(FDragIndex);
      ChangeSection(FCurrentSection);
    End;
End;

end.
